"""
ZSYNCER CONFIG

In the future we may switch to something like ZConfig.
For now, you should edit this file to configure global
options for your ZSyncers.
"""

# syncable:  a list of meta types you can sync by default.
# The management UI allows you to add more.
syncable = [
    'Control_Panel',
    'DTML Method', 
    'DTML Document',
    'Image',
    'File',
    'Page Template',
    'Script (Python)',
    'Z SQL Method',
    'Z Class',
    'Z Object',
    'Folder',
    ]

# sync_tab_classes:
# a list of (modulename, classname) tuples
# which will be patched to add a Sync tab in the ZMI.
# Errors importing any of these will be logged at startup.

sync_tab_classes = [
    ('OFS.Folder', 'Folder'),
    ('App.ApplicationManager', 'ApplicationManager'),
    ('App.Product','Product'),
    ('OFS.OrderedFolder', 'OrderedFolder'),
    ('Products.CMFCore.PortalFolder', 'PortalFolder'),# that does plone too!
    ('ZClasses.ZClass', 'ZObject'),
    #('ZClasses.Method', 'ZClassMethodsSheet'),  # doesn't work.
    ]

# diffable:
# a list of meta_types for which we can use the diff feature.

diffable = [
    'DTML Method',
    'DTML Document',
    'Page Template',
    'Script (Python)',
    'Document',
    'Text Element'
    ]

# diff_methods:
# a list of (meta_type, attribute-name) tuples which tell
# which attribute or method name to use when diffing.

diff_methods = {
    'DEFAULT': 'document_src',  # DTML, ZPT
    'Document': 'EditableBody', # CMF & Plone Documents
    'Text Element': 'value',    # CMFArticle
    }


# Colors for the UI
color_200 = 'green'
color_error = 'red'

colours = {
    'ok':'green',
    'out of date':'orange',
    'missing':'red',
    'extra':'#AA99FF',
    }

# descriptions:
# Some descriptive text to be used for status reports
# in the UI.
# Some day this may be i18nized... for now you can rewrite them here.

descriptions = {
    'ok':
    'this object is present on both destination and source and is in sync',
    
    'missing':
    'this object is present at source but not destination, '
    'it needs syncing',
    
    'extra':
    'this object is on destination but not source, ' 
    'consider deleting from destination', 

    'out of date':
    'this object is present on both the destination ' 
    'and source, but has been changed on source, it needs syncing',

    'default':
    '(no information available about this status)'
    }

# error_messages:
# descriptions of the possible HTTP response codes we may
# encounter when syncing.

error_messages = {
    '200':
    "Completed with no errors.",

    '403':
    "You are not allowed to do that."
    "You must have the same account and adequate permissions on the "
    "destination server.",

    '404':
    "Wasn't able to find this object on the destination server.",

    '500':
    "Server error while syncing."
    }

# reserved_names:
# IDs of objects in the zope app root which may not be synced
# (or even shown in the UI).
# These are taken from Application.py

reserved_names = (
    'standard_html_header',
    'standard_html_footer',
    'standard_error_message',
    'Control_Panel',
    'error_log',
    'browser_id_manager',
    'session_data_manager'
    )

