"""
Utils to help with global configuration of your ZSyncer installation.
"""
import sys, types
import zLOG
from Globals import DTMLFile
 
def _import(modpath, classname):
    # techniques swiped from
    # http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/223972
    # First get the module.
    try:
        # maybe we have it already...        
        aMod = sys.modules[modpath]
        if not isinstance(aMod, types.ModuleType):
            raise KeyError
    except KeyError:
        # nope, don't have it yet.        
        # The last [''] below is very important!
        aMod = __import__(modpath, globals(), locals(), [''])
        sys.modules[modpath] = aMod
    # Got a module, now get the class
    klass = getattr(aMod, classname)
    return klass


def _addSyncTab(klass, isZObject=0):
    """ add a Sync tab in the ZMI for this class """
    if isZObject:
        from ZClasses.Method import ZClassMethodsSheet
        ZClassMethodsSheet.sync_html = DTMLFile('dtml/SyncFolder', globals())
    else:
        klass.sync_html = DTMLFile('dtml/SyncFolder', globals())
    try:
        m = list(klass.manage_options)
    except TypeError:
        zLOG.LOG('ZSyncer', 100, 'problem with m_o of %s' % klass)
        raise
    # does the manage_options thing
    # already have this label? if not
    # add it. This aint perfect, since Sync
    # is not a unique name, but hey it works
    # for this
    has_tab = 0
    for opt in m:
        if opt.get('label', '') == 'Sync':
            has_tab = 1
            break

    # so it's not found, 
    # add the Sync tab.
    # security? that's an issue
    if not has_tab:
        if isZObject:
            m.append({'label':'Sync',
                      'action':'propertysheets/methods/sync_html'},)
        else:
            m.append({'label':'Sync', 'action':'sync_html'},)

        klass.manage_options = tuple(m)

