""" ZSyncerTool

a CMF tool that wraps and provides a UI for ZSyncer.

Work in progress, may not actually do much yet!
"""

from Globals import InitializeClass, DTMLFile
from AccessControl import ClassSecurityInfo
from OFS.SimpleItem import SimpleItem

from Products.CMFCore.utils import UniqueObject, getToolByName
from Products.CMFCore.CMFCorePermissions import ManagePortal
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from Products.CMFCore.ActionInformation import ActionInformation
from Products.CMFCore.Expression import Expression

from OFS.Folder import Folder
from ZSyncer import ZSyncer, manage_addZSyncer, ZSYNC_PERMISSION
from types import StringType

_upgradePaths = {}

class ZSyncerTool(UniqueObject, Folder, ActionProviderBase):
    """
    a CMF tool that wraps and provides a UI for ZSyncer.

    XXX we have no UI yet, it will go in skins/.
    
    XXX need to fix some calls to old method names
    """
    id = 'portal_zsyncer'
    meta_type = 'Portal ZSyncer Tool'
    _default_zsyncer = 'Default'

    manage_options = ActionProviderBase.manage_options + Folder.manage_options
    security = ClassSecurityInfo()

    _actions = [ 
       ActionInformation(
           id='synchronisation', 
           title='Synchronise', 
           action=Expression(text='string: ${folder_url}/zsyncer_folderview'),
           condition=Expression(text='python: folder is object'),
           permissions=(ZSYNC_PERMISSION,), 
           category='folder', 
           visible=1 ),
       ActionInformation(
           id='synchronisation',
           title='Synchronise',
           action=Expression(text='string: zsyncer_objectview'),
	   condition=Expression(text='python: not folder is object'),
           permissions=(ZSYNC_PERMISSION,),
           category='object',
           visible=1),
       ]

    def filtered_meta_types(self):
        """Filter meta types
        """
        types = Folder.filtered_meta_types(self)
        l = []
        for t in types:
            print t['name'], ZSyncer.meta_type
            if t['name'] == ZSyncer.meta_type:
               l.append(t)
        return l

    security.declarePrivate('listActions')
    def listActions(self, info=None):
        """Return actions provided by tool
        """
        return self._actions

    def manage_afterAdd(self, *args, **kwargs):
        """After a ZSyncerTool is added
        """
        # add a default zSyncer
        if self._default_zsyncer not in self.objectIds():
            manage_addZSyncer(self, self._default_zsyncer)

    def obj_compare(self, obj, syncer=None):
        """is this object in or out of sync with the syncer,
        default if syncer is none
        """
        syncer = self._getZSyncer(syncer)
        return syncer.manage_compare(obj)

    def obj_diff(self, obj, syncer=None):
        """is there a diff for this object
        """
        syncer = self._getZSyncer(syncer)
        return syncer.manage_diffObject(obj)

    def obj_sync(self, obj, syncer=None):
        """sync object, default if syncer is none
        """
        syncer = self._getZSyncer(syncer)
        return syncer.manage_exportXMLRPC(obj)

    def obj_delete(self, obj, syncer=None):
        """delete object, default if syncer is none
        """
        syncer = self._getZSyncer(syncer)
        return syncer.manage_deleteXMLRPC(obj)

    ################################################

    def _getZSyncer(self, syncer):
        """get the default zsyncer
        """
        if syncer is None:
            syncer = self._default_zsyncer
        obj = getattr(self, syncer, None)
        if obj is None:
            raise ValueError, "ZSyncer %s is not found" % syncer
        return obj


def manage_addZSyncerTool(self, id=None, REQUEST=None, 
                          submit=None):
    """add an instance to a folder
    """
    # normally, the defaut id is used.
    if id is None: id = ZSyncerTool.id
    self._setObject(id, ZSyncerTool(id))
    obj = getattr(self, id)
    if REQUEST is not None:
        obj.manage_changeProperties(REQUEST) 
        try: url=self.DestinationURL() 
        except: url=REQUEST['URL1'] 
        url = url + "/manage_main" 
        REQUEST.RESPONSE.redirect(url) 

constructors = (manage_addZSyncerTool,)

InitializeClass(ZSyncerTool)

