"""
HTTP basic authorization for XML-RPC
"""

# Thanks Amos and Chris at DC
# http://www.zope.org/Members/Amos/XML-RPC

# path to xmlrpclib, works fine in Zope but when running from the command line
# seems to fail. Annoying.
# import sys
# sys.path.insert(0, r'd:\XMLTest1\lib\python')

import string, xmlrpclib, httplib
from base64 import encodestring

def Server(url, username, password):
    """
    Factory for our transport - we need to pass authentication headers ...

    There is also some naf processing whereby the host string has had the
    type removed by the time the transport's request function is called.
    We need to be able to construct the correct transport in this
    method - hence the use_ssl hack.
    """
    t = BasicAuthTransport(url.startswith('https://'), username, password)
    return xmlrpclib.Server(url, t)

class BasicAuthTransport(xmlrpclib.Transport):

    has_ssl = httplib.__dict__.has_key("HTTPSConnection")

    def __init__(self, use_ssl, username=None, password=None):
        self.username = username
        self.password = password
        self.verbose = None
        self.use_ssl = self.has_ssl and use_ssl

    def request(self, host, handler, request_body, verbose=None):
        # issue XML-RPC request

        if self.use_ssl:
            h = httplib.HTTPS(host)
        else:
            h = httplib.HTTP(host)

        h.putrequest("POST", handler)

        # required by HTTP/1.1
        h.putheader("Host", host)
        h.putheader("Connection", "close")

        # required by XML-RPC
        h.putheader("User-Agent", self.user_agent)
        h.putheader("Content-Type", "text/xml")
        h.putheader("Content-Length", str(len(request_body)))

        # basic auth
        if self.username is not None and self.password is not None:
            h.putheader("AUTHORIZATION", "Basic %s" % string.replace(
                    encodestring("%s:%s" % (self.username, self.password)),
                    "\012", ""))
        h.endheaders()

        if request_body: h.send(request_body)
        errcode, errmsg, headers = h.getreply()

        if errcode != 200:
            raise xmlrpclib.ProtocolError(host + handler, errcode, errmsg, headers)
        
        file = h.getfile()

        return self.parse_response(file) 

if __name__=='__main__':
    pass
